@@ -6,7 +6,6 @@
 --
 -- ==============================================================
 \set ON_ERROR_STOP 1
-
 --set default_transaction_read_only to off;
 
 -- --------------------------------------------------------------
@@ -18,21 +17,19 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.1.9 (database v16.9)',
-	'GNUmed 1.1.9 Release Notes:
+	'Release Notes for GNUmed 1.1.12 (database v16.12)',
+	'GNUmed 1.1.12 Release Notes:
 
-	1.1.9
+	1.1.12
 
-FIX: completely rip out wx.lib.pubsub use
+FIX: exception with certain invalid placeholders [thanks S.Reus]
+FIX: add missing encoding detection [thanks Andrew]
+FIX: broken health issue creation from its PRW [thanks S.Reus]
 
-	1.1.8
-
-FIX: exception on accessing diagnostic certainty phrasewheel [thanks J.Busser]
-FIX: cannot pack with pyInstaller due to pubsub v1 API [thanks S.Hilbert]
-
-IMPROVED: try robustifying wx.lib.pubsub listener facing pyInstaller damage [thanks MM]
-IMPROVED: make opening URLs work better with Python 2.6 [thanks MM]
-IMPROVED: detection of connection loss
+IMPROVED: robustify os.startfile() use [thanks S.Hilbert]
+IMPROVED: robustify auto-setting of encounter.last_affirmed
+IMPROVED: robustify validity checks of cFuzzyTimestampInput [thanks S.Reus]
+IMPROVED: overly eager page number collision check [thanks S.Hilbert]
 ');
 
 -- --------------------------------------------------------------
